@@ -31,7 +31,6 @@ package Maintainers;
 	'jand'		=> 'Jan Dubois <jand@activestate.com>',
 	'jdhedden'	=> 'Jerry D. Hedden <jdhedden@cpan.org>',
 	'jhi'		=> 'Jarkko Hietaniemi <jhi@cpan.org>',
-	'jpeacock'	=> 'John Peacock <jpeacock@rowman.com>',
 	'jstowe'	=> 'Jonathan Stowe <jstowe@cpan.org>',
 	'jv'		=> 'Johan Vromans <jv@cpan.org>',
 	'kane'		=> 'Jos Boumans <kane@cpan.org>',
@@ -513,13 +512,11 @@ package Maintainers;
 		'CPAN'		=> 1,
 		},
 
-	# NB. tests are located in t/Module_Pluggable to avoid directory
-	# depth issues on VMS
 	'Module::Pluggable' =>
 		{
 		'MAINTAINER'	=> 'simonw',
 		'FILES'		=> q[lib/Module/Pluggable lib/Module/Pluggable.pm
-				     lib/Devel/InnerPackage.pm t/Module_Pluggable],
+				     lib/Devel/InnerPackage.pm],
 		'CPAN'		=> 1,
 		},
 
@@ -684,13 +681,6 @@ package Maintainers;
 		'CPAN'		=> 1,
 		},
 
-	'Sys::Syslog' =>
-		{
-		'MAINTAINER'	=> 'saper',
-		'FILES'		=> q[ext/Sys/Syslog],
-		'CPAN'		=> 1,
-		},
-
 	'TabsWrap' =>
 		{
 		'MAINTAINER'	=> 'muir',
@@ -879,20 +869,6 @@ package Maintainers;
 		'CPAN'		=> 0,
 		},
 
-	'version' =>
-		{
-		'MAINTAINER'	=> 'jpeacock',
-		'FILES'		=> q[lib/version.pm lib/version.pod lib/version.t],
-		'CPAN'		=> 1,
-		},
-
-	'Perl6::Form' =>
-		{
-		'MAINTAINER'	=> 'dconway',
-		'FILES'		=> q[ext/Perl6-Form],
-		'CPAN'		=> 1,
-		},
-
 	);
 
 1;
