@@ -197,8 +197,8 @@ sub ret_backtrace {
   $i++;
 
   my $tid_msg = '';
-  if (defined &threads::tid) {
-    my $tid = threads->tid;
+  if (defined &Thread::tid) {
+    my $tid = Thread->self->tid;
     $tid_msg = " thread $tid" if $tid;
   }
 
@@ -218,8 +218,8 @@ sub ret_summary {
   $i++;
 
   my $tid_msg = '';
-  if (defined &threads::tid) {
-    my $tid = threads->tid;
+  if (defined &Thread::tid) {
+    my $tid = Thread->self->tid;
     $tid_msg = " thread $tid" if $tid;
   }
 
